@@ -3,11 +3,13 @@ from proxy_tools import proxy
 from .clb_client import ClbClient
 from .cdn_client import CdnClient
 from .cfs_client import CfsClient
+from .vpc_client import VpcClient
 
 prod_mapper = {
     'clb': ClbClient,
     'cdn': CdnClient,
-    'cfs': CfsClient
+    'cfs': CfsClient,
+    'vpc': VpcClient,
 }
 
 
@@ -31,3 +33,8 @@ def cdn_client():
 @proxy
 def cfs_client():
     return get_current_client('cfs')
+
+
+@proxy
+def vpc_client():
+    return get_current_client('vpc')
